Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Connect Cases.

Actions, resources, and condition keys for Amazon Connect Cases - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Connect Cases

Amazon Connect Cases (service prefix: `cases` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Connect Cases
- Resource types defined by Amazon Connect Cases
- Condition keys for Amazon Connect Cases

## Actions defined by Amazon Connect Cases

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BatchGetField | Grants permission to retrieve information about the fields in the case domain | Read | Domain* |  |
Field* |  |
BatchPutFieldOptions | Grants permission to update the field options in the case domain | Write | Domain* |  |
Field* |  |
CreateCase | Grants permission to create a case in the case domain | Write | Case* |  |
Domain* |  |
Field* |  |
Template* |  |
| connect:UserArn |
CreateDomain | Grants permission to create a new case domain | Write |  |  |
CreateField | Grants permission to create a field in the case domain | Write | Domain* |  |
Field* |  |
CreateLayout | Grants permission to create a layout in the case domain | Write | Domain* |  |
Layout* |  |
CreateRelatedItem | Grants permission to create a related item associated to a case in the case domain | Write | Case* |  |
Domain* |  |
RelatedItem* |  |
| connect:UserArn |
CreateTemplate | Grants permission to create a template in the case domain | Write | Domain* |  |
Layout* |  |
Template* |  |
DeleteDomain | Grants permission to delete the domain | Write | Domain* |  |
DeleteField | Grants permission to delete the field in the case domain | Write | Domain* |  |
Field* |  |
DeleteLayout | Grants permission to delete the layout in the case domain | Write | Domain* |  |
Layout* |  |
DeleteRelatedItem [permission only] | Grants permission to delete a related item associated to a case in the case domain | Write | Case* |  |
Domain* |  |
RelatedItem* |  |
DeleteTemplate | Grants permission to delete the template in the case domain | Write | Domain* |  |
Template* |  |
GetCase | Grants permission to retrieve information about a case in the case domain | Read | Case* |  |
Domain* |  |
Field* |  |
GetCaseAuditEvents | Grants permission to view audit history of a case | Read | Case* |  |
Domain* |  |
GetCaseEventConfiguration | Grants permission to retrieve information about the case event configuraton in the case domain | Read | Domain* |  |
GetDomain | Grants permission to retrieve information about the case domain | Read | Domain* |  |
GetLayout | Grants permission to retrieve information about the layout in the case domain | Read | Domain* |  |
Layout* |  |
GetTemplate | Grants permission to retrieve information about the template in the case domain | Read | Domain* |  |
Template* |  |
ListCasesForContact | Grants permission to list cases for a specific contact in the case domain | List | Domain* |  |
ListDomains | Grants permission to list all domains in the aws account | List |  |  |
ListFieldOptions | Grants permission to list field options for a single select field in the case domain | List | Domain* |  |
Field* |  |
ListFields | Grants permission to list fields in the case domain | List | Domain* |  |
ListLayouts | Grants permission to list layouts in the case domain | List | Domain* |  |
ListTagsForResource | Grants permission to list the tags for the specified resource | Read |  |  |
ListTemplates | Grants permission to list templates in the case domain | List | Domain* |  |
PutCaseEventConfiguration | Grants permission to insert or update the case event configuration in the case domain | Write | Domain* |  |
SearchCases | Grants permission to search for cases in the case domain | Read | Domain* |  |
SearchRelatedItems | Grants permission to search for related items associated to the case in the case domain | Read | Case* |  |
Domain* |  |
TagResource | Grants permission to add the specified tags to the specified resource | Tagging | Case |  |
Domain |  |
Field |  |
Layout |  |
RelatedItem |  |
Template |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove the specified tags from the specified resource | Tagging | Case |  |
Domain |  |
Field |  |
Layout |  |
RelatedItem |  |
Template |  |
| aws:TagKeys |
UpdateCase | Grants permission to update the field values on the case in the case domain | Write | Case* |  |
Domain* |  |
Field* |  |
| connect:UserArn |
UpdateField | Grants permission to update the field in the case domain | Write | Domain* |  |
Field* |  |
UpdateLayout | Grants permission to update the layout in the case domain | Write | Domain* |  |
Layout* |  |
UpdateTemplate | Grants permission to update the template in the case domain | Write | Domain* |  |
Template* |  |

## Resource types defined by Amazon Connect Cases

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
Case | `arn:$ { Partition}:cases:$ { Region}:$ { Account}:domain/$ { DomainId}/case/$ { CaseId}` | aws:ResourceTag/${TagKey}
Domain | `arn:$ { Partition}:cases:$ { Region}:$ { Account}:domain/$ { DomainId}` | aws:ResourceTag/${TagKey}
Field | `arn:$ { Partition}:cases:$ { Region}:$ { Account}:domain/$ { DomainId}/field/$ { FieldId}` | aws:ResourceTag/${TagKey}
Layout | `arn:$ { Partition}:cases:$ { Region}:$ { Account}:domain/$ { DomainId}/layout/$ { LayoutId}` | aws:ResourceTag/${TagKey}
RelatedItem | `arn:$ { Partition}:cases:$ { Region}:$ { Account}:domain/$ { DomainId}/case/$ { CaseId}/related-item/$ { RelatedItemId}` | aws:ResourceTag/${TagKey}
Template | `arn:$ { Partition}:cases:$ { Region}:$ { Account}:domain/$ { DomainId}/template/$ { TemplateId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Connect Cases

Amazon Connect Cases defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by tags associated with the resource | String
aws:TagKeys | Filters access by tag keys that are passed in the request | ArrayOfString
connect:UserArn | Filters access by connect's UserArn | ARN

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.